============
Installation
============


To install the latest PyPI release, simply run:

.. code-block:: bash

    pip install imitation


Alternatively, you can install the latest version of ``imitation`` from source. This is useful if you wish to contribute to the development of ``imitation``, or if you need features that have not yet been made available in a stable release:

.. code-block:: bash

    git clone http://github.com/HumanCompatibleAI/imitation
    cd imitation
    pip install -e .


**Optional Mujoco Dependency**

Follow instructions to install `mujoco\_py v1.5 here`_.

.. _mujoco_py v1.5 here:
    https://github.com/openai/mujoco-py/tree/498b451a03fb61e5bdfcb6956d8d7c881b1098b5#install-mujoco
